summaryrefslogtreecommitdiff
path: root/tests/tset_z_exp.c
diff options
context:
space:
mode:
authorzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2010-02-22 17:23:27 +0000
committerzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2010-02-22 17:23:27 +0000
commit4fc10b29bcfd5b0ddd4aee1021235fb669ef302e (patch)
treee4fac1e8bc3208aa47b3c319fd06e94048b43a56 /tests/tset_z_exp.c
parent5980e3509181df843fe8dcb30f46c9dfb51b0116 (diff)
downloadmpfr-4fc10b29bcfd5b0ddd4aee1021235fb669ef302e.tar.gz
changed mpfr_get_z_exp -> mpfr_get_z_2exp (old function)
mpfr_set_z_exp -> mpfr_set_z_2exp (new function) git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@6707 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'tests/tset_z_exp.c')
-rw-r--r--tests/tset_z_exp.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/tset_z_exp.c b/tests/tset_z_exp.c
index 7dcc0093d..d2526bb08 100644
--- a/tests/tset_z_exp.c
+++ b/tests/tset_z_exp.c
@@ -1,4 +1,4 @@
/* Test file for mpfr_set_z_exp.
Copyright 1999, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
Contributed by the Arenaire and Cacao projects, INRIA.
@@ -48,10 +48,10 @@ check0 (void)
for(r = 0; r < MPFR_RND_MAX; r++)
{
e = randexp ();
- inexact = mpfr_set_z_exp (x, y, e, (mpfr_rnd_t) r);
+ inexact = mpfr_set_z_2exp (x, y, e, (mpfr_rnd_t) r);
if (!MPFR_IS_ZERO(x) || !MPFR_IS_POS(x) || inexact)
{
- printf ("mpfr_set_z_exp(x,0,e) failed for e=%ld, rnd=%s\n", e,
+ printf ("mpfr_set_z_2exp(x,0,e) failed for e=%ld, rnd=%s\n", e,
mpfr_print_rnd_mode ((mpfr_rnd_t) r));
exit (1);
}
@@ -75,11 +75,11 @@ check (long i, mpfr_rnd_t rnd)
mpz_init (z);
mpz_set_ui (z, i);
e = randexp ();
- mpfr_set_z_exp (f, z, e, rnd);
+ mpfr_set_z_2exp (f, z, e, rnd);
mpfr_div_2si (f, f, e, rnd);
if (mpfr_get_si (f, MPFR_RNDZ) != i)
{
- printf ("Error in mpfr_set_z_exp for i=%ld e=%ld rnd_mode=%d\n",
+ printf ("Error in mpfr_set_z_2exp for i=%ld e=%ld rnd_mode=%d\n",
i, e, rnd);
printf ("expected %ld\n", i);
mpfr_printf ("got %Re\n", f);
@@ -1,4 +1,4 @@
-/* Test file for mpfr_set_z_exp.
+/* Test file for mpfr_set_z_2exp.
Copyright 1999, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
Contributed by the Arenaire and Cacao projects, INRIA.